/*-
 * Copyright (c) 2016 Varnish Software AS
 * All rights reserved.
 *
 * Author: Poul-Henning Kamp <phk@phk.freebsd.dk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * RFC7540 section 11.2
 */

/*lint -save -e525 -e539 */

#ifdef H2_FRAME
H2_FRAME(
	/* lower */		data,
	/* upper */		DATA,
	/* type */		0x0,
	/* flags */		0x09,
	/* rx_err_req0 */	1,			// rfc7540,l,1758,1761
	/* rx_err_req */	0,
	/* rx_err_maxid */	1,
	/* tx_flow_control */	1,
	/* tx_followup */	H2_F_DATA,
	/* tx_final_flags */	0x01,			// rfc7540,l,1750,1753
	/* overhead */		0
)

H2_FRAME(
	/* lower */		headers,
	/* upper */		HEADERS,
	/* type */		0x1,
	/* flags */		0x2d,
	/* rx_err_req0 */	1,			// rfc7540,l,1876,1879
	/* rx_err_req */	0,
	/* rx_err_maxid */	0,			// rfc7540,l,938,940
	/* tx_flow_control */	0,
	/* tx_followup */	H2_F_CONTINUATION,
	/* tx_final_flags */	0x04,			// rfc7540,l,1855,1857
	/* overhead */		0
)

H2_FRAME(
	/* lower */		priority,
	/* upper */		PRIORITY,
	/* type */		0x2,
	/* flags */		0x00,
	/* rx_err_req0 */	1,			// rfc7540,l,1933,1936
	/* rx_err_req */	0,
	/* rx_err_maxid */	0,			// rfc7540,l,938,940
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		rst_stream,
	/* upper */		RST_STREAM,
	/* type */		0x3,
	/* flags */		0x00,
	/* rx_err_req0 */	1,			// rfc7540,l,1993,1996
	/* rx_err_req */	0,
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		settings,
	/* upper */		SETTINGS,
	/* type */		0x4,
	/* flags */		0x01,
	/* rx_err_req0 */	0,
	/* rx_err_req */	1,			// rfc7540,l,2052,2056
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		push_promise,
	/* upper */		PUSH_PROMISE,
	/* type */		0x5,
	/* flags */		0x0c,
	/* rx_err_req0 */	1,			// rfc7540,l,2262,2263
	/* rx_err_req */	0,
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	H2_F_CONTINUATION,
	/* tx_final_flags */	0x04,			// rfc7540,l,2249,2251
	/* overhead */		1
)

H2_FRAME(
	/* lower */		ping,
	/* upper */		PING,
	/* type */		0x6,
	/* flags */		0x01,
	/* rx_err_req0 */	0,
	/* rx_err_req */	1,			// rfc7540,l,2359,2362
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		goaway,
	/* upper */		GOAWAY,
	/* type */		0x7,
	/* flags */		0x00,
	/* rx_err_req0 */	0,
	/* rx_err_req */	1,			// rfc7540,l,2432,2435
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		window_update,
	/* upper */		WINDOW_UPDATE,
	/* type */		0x8,
	/* flags */		0x00,
	/* rx_err_req0 */	0,
	/* rx_err_req */	0,
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	NULL,
	/* tx_final_flags */	0,
	/* overhead */		1
)

H2_FRAME(
	/* lower */		continuation,
	/* upper */		CONTINUATION,
	/* type */		0x9,
	/* flags */		0x04,
	/* rx_err_req0 */	1,			// rfc7540,l,2764,2767
	/* rx_err_req */	0,
	/* rx_err_maxid */	1,
	/* tx_flow_control */	0,
	/* tx_followup */	H2_F_CONTINUATION,
	/* tx_final_flags */	0x04,			// rfc7540,l,2753,2754
	/* overhead */		0
)
  #undef H2_FRAME
#endif

#ifdef H2_FRAME_FLAGS
/*		 lower,			upper,				flag */
  H2_FRAME_FLAGS(none,			NONE,				0x00)
  H2_FRAME_FLAGS(data_end_stream,	DATA_END_STREAM,		0x01)
  H2_FRAME_FLAGS(data_padded,		DATA_PADDED,			0x08)
  H2_FRAME_FLAGS(headers_end_stream,	HEADERS_END_STREAM,		0x01)
  H2_FRAME_FLAGS(headers_end_headers,	HEADERS_END_HEADERS,		0x04)
  H2_FRAME_FLAGS(headers_padded,	HEADERS_PADDED,			0x08)
  H2_FRAME_FLAGS(headers_priority,	HEADERS_PRIORITY,		0x20)
  H2_FRAME_FLAGS(settings_ack,		SETTINGS_ACK,			0x01)
  H2_FRAME_FLAGS(push_promise_end_headers,PUSH_PROMISE_END_HEADERS,	0x04)
  H2_FRAME_FLAGS(push_promise_padded,	PUSH_PROMISE_PADDED,		0x08)
  H2_FRAME_FLAGS(ping_ack,		PING_ACK,			0x01)
  H2_FRAME_FLAGS(continuation_end_headers,CONTINUATION_END_HEADERS,	0x04)
  #undef H2_FRAME_FLAGS
#endif

/*lint -restore */
